local using_methane = settings.startup["adamo-carbon-methane"].value
local using_wellhead = settings.startup["adamo-carbon-wellhead"].value

function add_recipe_to_tech(tech_name,recipe_name)
	local tech = data.raw["technology"][tech_name]
	if tech then
		if not tech.effects then
			tech.effects = {{
				type="unlock-recipe",
				recipe=recipe_name
			}}
		else
			table.insert(tech.effects, {
				type="unlock-recipe",
				recipe=recipe_name
			})
		end
	end
end

function apply_data() 
	if using_wellhead or using_wellhead then
		data:extend({
			gas_tech
		})
	end

	data:extend({
		natural_gas_ac,
		natural_gas_resource,
	
		crude_oil_fuel_recipe,
		
		gf_boiler_entity,
		gf_boiler_item,
		gf_boiler_recipe,
	})
	add_recipe_to_tech(
		"oil-processing",
		"adamo-carbon-solid-fuel-from-crude-oil"
	)
	add_recipe_to_tech(
		"fluid-handling",
		"adamo-carbon-gas-fired-boiler"
	)

	if using_wellhead then
		data:extend({
			gas_resource_category,

			natural_gas_wellhead_entity,
			natural_gas_wellhead_item,
			natural_gas_wellhead_recipe,
		})
		if not using_methane then
			add_recipe_to_tech(
				"oil-processing",
				"adamo-carbon-gas-wellhead"
			)
		end
		add_recipe_to_tech(
			"adamo-carbon-gas-processing",
			"adamo-carbon-gas-wellhead"
		)
	end

	if using_methane then
		data:extend({
			methane_fluid,
			natural_gas_fluid,
	
			natural_gas_processing_recipe,
			adv_natural_gas_processing_recipe,
			activated_fuel_recipe,
			LPG_cracking_recipe,
			FT_basic_recipe,
			FT_adv_recipe,
			rocket_fuel_recipe,
		})
		add_recipe_to_tech(
			"rocket-fuel",
			"adamo-carbon-rocket-fuel"
		)
		add_recipe_to_tech(
			"advanced-oil-processing",
			"adamo-carbon-advanced-natural-gas-processing"
		)
		add_recipe_to_tech(
			"adamo-carbon-gas-processing",
			"adamo-carbon-activated-solid-fuel"
		)
		add_recipe_to_tech(
			"advanced-oil-processing",
			"adamo-carbon-petroleum-gas-cracking"
		)
		add_recipe_to_tech(
			"advanced-oil-processing",
			"adamo-carbon-basic-FT-process"
		)
		add_recipe_to_tech(
			"adamo-carbon-gas-processing",
			"adamo-carbon-basic-natural-gas-processing"
		)
		add_recipe_to_tech(
			"adamo-carbon-gas-processing",
			"oil-refinery"
		)
		add_recipe_to_tech(
			"adamo-carbon-gas-processing",
			"chemical-plant"
		)
		add_recipe_to_tech(
			"adamo-carbon-gas-processing",
			"solid-fuel-from-petroleum-gas"
		)
		add_recipe_to_tech(
			"coal-liquefaction",
			"adamo-carbon-advanced-FT-process"
		)
	end
end

gas_resource_category = {
		type = "resource-category",
		name = "adamo-carbon-gas"
}

gas_tech = {
	type = "technology",
	name = "adamo-carbon-gas-processing",
	icon_size = 132,
	icon = "__adamo-carbon__/graphics/technology/gas-processing.png",
	prerequisites = {"fluid-handling"},
	unit = {
		count = 100,
		ingredients = {{
				"automation-science-pack",1
			},{
				"logistic-science-pack",1
		}},
		time = 30,
	},
	order = "d-a1",
}


natural_gas_ac = {
	type = "autoplace-control",
	name = "adamo-carbon-natural-gas",
	richness = true,
	order = "b-g",
	category = "resource"
}

resource_autoplace = require("resource-autoplace");
resource_autoplace.initialize_patch_set("adamo-carbon-natural-gas",false)
natural_gas_resource = {
	type = "resource",
	name = "adamo-carbon-natural-gas",
	icon = "__adamo-carbon__/graphics/icons/natural-gas.png",
	icon_size = 32,
	flags = {"placeable-neutral"},
	category = "adamo-carbon-gas",
	order="a-b-b",
	infinite = true,
	highlight = true,
	minimum = 60000,
	normal = 300000,
	infinite_depletion_amount = 10,
	resource_patch_search_radius = 12,
	tree_removal_probability = 0.7,
	tree_removal_max_distance = 32 * 32,
	minable = {
		mining_time = 1,
		results = {{
				type = "fluid",
				name = "adamo-carbon-natural-gas",
				amount_min = 10,
				amount_max = 10,
				probability = 1
		}}
	},
	collision_box = {{ -1.4, -1.4}, {1.4, 1.4}},
	selection_box = {{ -0.5, -0.5}, {0.5, 0.5}},
	autoplace = resource_autoplace.resource_autoplace_settings {
		name = "adamo-carbon-natural-gas",
		order = "d",
		base_density = 8.2,
		base_spots_per_km2 = 1.8,
		random_probability = 1/42,
		random_spot_size_minimum = 1,
		random_spot_size_maximum = 1,
		additional_richness = 220000,
		has_starting_area_placement = true,
		regular_rq_factor_multiplier = 1
	},
	stage_counts = {0},
	stages = {
		sheet = {
			filename = "__adamo-carbon__/graphics/entity/natural-gas.png",
			priority = "extra-high",
			width = 75,
			height = 61,
			frame_count = 4,
			variation_count = 1
	}},
	map_color = {r=1, g=80/255, b=80/255},
	map_grid = false
}
if not using_methane then
	natural_gas_resource.minable = {
		mining_time = 1,
		results = {{
				type = "fluid",
				name = "petroleum-gas",
				amount_min = 6,
				amount_max = 6,
				probability = 1
		}}
	}
	natural_gas_resource.icon = "__base__/graphics/icons/fluid/petroleum-gas.png"
end
if not using_wellhead then 
	natural_gas_resource.category = "basic-fluid"
end

natural_gas_fluid = {
	type = "fluid",
	name = "adamo-carbon-natural-gas",
	order = "a[fluid]-b[adamo-carbon-natural-gas]",
	icon = "__adamo-carbon__/graphics/icons/natural-gas.png",
	icon_size = 32,
	base_color = {
		r = 255/255,
		g = 153/255,
		b = 153/255,
		a = 0.5
	},
	flow_color = {
		r = 255/255,
		g = 153/255,
		b = 153/255,
		a = 0.5
	},
	default_temperature = 25,
	max_temperature = 750,
	heat_capacity = "0.05KJ",
	emissions_multiplier=0.5
}
methane_fluid = {
	type = "fluid",
	name = "adamo-carbon-methane",
	order = "a[fluid]-f[adamo-carbon-methane]",
	icon = "__adamo-carbon__/graphics/icons/methane.png",
	icon_size = 32,
	base_color = {
		r = 255/255,
		g = 153/255,
		b = 153/255,
		a = 0.2
	},
	flow_color = {
		r = 255/255,
		g = 153/255,
		b = 153/255,
		a = 0.2
	},
	default_temperature = 25,
	max_temperature = 750,
	heat_capacity = "0.05KJ",
	emissions_multiplier=0.5,
}


natural_gas_wellhead_entity = util.table.deepcopy(data.raw["mining-drill"].pumpjack)
natural_gas_wellhead_entity.name = "adamo-carbon-gas-wellhead"
natural_gas_wellhead_entity.resource_categories = {"adamo-carbon-gas"}
natural_gas_wellhead_entity.energy_source.emissions_per_minute = 6
natural_gas_wellhead_entity.energy_usage = "60kW"
natural_gas_wellhead_entity.icon = "__adamo-carbon__/graphics/icons/natural-gas-wellhead.png"
natural_gas_wellhead_entity.icon_size = 32
natural_gas_wellhead_entity.minable.result = "adamo-carbon-gas-wellhead"
natural_gas_wellhead_entity.resistances = {{
		type = "fire",
		percent = 70
}}
natural_gas_wellhead_entity.animations = {
	frame_count = 1,
	filename = "__adamo-carbon__/graphics/blank.png",
	size = 32,
}
natural_gas_wellhead_entity.collision_mask = {"item-layer", "object-layer", "water-tile"}
gf_boiler_entity = util.table.deepcopy(data.raw.boiler.boiler)
gf_boiler_entity.name = "adamo-carbon-gas-fired-boiler"
gf_boiler_entity.icon = "__adamo-carbon__/graphics/icons/gas-fired-boiler.png"
gf_boiler_entity.icon_size = 32
gf_boiler_entity.minable.result = "adamo-carbon-gas-fired-boiler"
gf_boiler_entity.energy_source = {
	type = "fluid",
	fluid_box = {
		base_area = 1,
		height = 2,
		base_level = -1,
		pipe_covers = pipecoverspictures(),
		pipe_picture = assembler1pipepictures(),
		pipe_connections = {
			{type = "input", position = {0, 1.5}},
		},
	},
	burns_fluid = true,
	scale_fluid_usage = true,
	effectivity = 1,
	emissions_per_minute = 30,
	smoke = {{
			name = "smoke",
			north_position = util.by_pixel(-38, -47.5),
			south_position = util.by_pixel(38.5, -32),
			east_position = util.by_pixel(20, -70),
			west_position = util.by_pixel(-19, -8.5),
			frequency = 15,
			starting_vertical_speed = 0.3,
			starting_frame_deviation = 0
	}},
	light_flicker = {
		--minimum_intensity = 0.8,
		--maximum_intensity = 1,
		--color = {r=0.75,g=0.1,b=0.1,a=0.5},
		color = {r=1,g=0.5,b=0.5,a=0.5},
		minimum_light_size = 0.1,
		light_intensity_to_size_coefficient = 1
	}
}
gf_boiler_entity.fire_flicker_enabled = false
gf_boiler_entity.fire_glow_flicker_enabled = false
gf_boiler_entity.fire = {}
gf_boiler_entity.fire_glow.north.filename = 
	"__adamo-carbon__/graphics/entity/"..
	"gf-boiler-N-light.png"
gf_boiler_entity.fire_glow.south.filename = 
	"__adamo-carbon__/graphics/entity/"..
	"gf-boiler-S-light.png"
gf_boiler_entity.fire_glow.east.filename = 
	"__adamo-carbon__/graphics/entity/"..
	"gf-boiler-E-light.png"
gf_boiler_entity.fire_glow.west.filename = 
	"__adamo-carbon__/graphics/entity/"..
	"gf-boiler-W-light.png"
gf_boiler_entity.fire_glow.north.hr_version.filename = 
	"__adamo-carbon__/graphics/entity/"..
	"hr-gf-boiler-N-light.png"
gf_boiler_entity.fire_glow.south.hr_version.filename = 
	"__adamo-carbon__/graphics/entity/"..
	"hr-gf-boiler-S-light.png"
gf_boiler_entity.fire_glow.east.hr_version.filename = 
	"__adamo-carbon__/graphics/entity/"..
	"hr-gf-boiler-E-light.png"
gf_boiler_entity.fire_glow.west.hr_version.filename = 
	"__adamo-carbon__/graphics/entity/"..
	"hr-gf-boiler-W-light.png"
gf_boiler_entity.fire_glow.north.apply_runtime_tint = true
gf_boiler_entity.fire_glow.south.apply_runtime_tint = true
gf_boiler_entity.fire_glow.east.apply_runtime_tint = true
gf_boiler_entity.fire_glow.west.apply_runtime_tint = true
gf_boiler_entity.fire_glow.north.tint={r=1,g=0.6,b=0.6,a=0.4}
gf_boiler_entity.fire_glow.south.tint={r=1,g=0.6,b=0.6,a=0.4}
gf_boiler_entity.fire_glow.east.tint={r=1,g=0.6,b=0.6,a=0.4}
gf_boiler_entity.fire_glow.west.tint={r=1,g=0.6,b=0.6,a=0.4}
gf_boiler_entity.fire_glow.north.blend_mode = "additive-soft"
gf_boiler_entity.fire_glow.south.blend_mode = "additive-soft"
gf_boiler_entity.fire_glow.east.blend_mode = "additive-soft"
gf_boiler_entity.fire_glow.west.blend_mode = "additive-soft"

natural_gas_wellhead_item = util.table.deepcopy(data.raw.item.pumpjack)
natural_gas_wellhead_item.name = "adamo-carbon-gas-wellhead"
natural_gas_wellhead_item.icon = "__adamo-carbon__/graphics/icons/natural-gas-wellhead.png"
natural_gas_wellhead_item.order = "b[fluids]-b[adamo-carbon-gas-wellhead]"
natural_gas_wellhead_item.place_result = "adamo-carbon-gas-wellhead"
natural_gas_wellhead_item.stack_size = 50
gf_boiler_item = util.table.deepcopy(data.raw.item.boiler)
gf_boiler_item.name = "adamo-carbon-gas-fired-boiler"
gf_boiler_item.icon_size = 32
gf_boiler_item.icon = "__adamo-carbon__/graphics/icons/gas-fired-boiler.png"
gf_boiler_item.order = "b[steam-power]-b[adamo-carbon-gas-fired-boiler]"
gf_boiler_item.place_result = "adamo-carbon-gas-fired-boiler"

natural_gas_processing_recipe = {
	type = "recipe",
	name = "adamo-carbon-basic-natural-gas-processing",
	category = "oil-processing",
	enabled = false,
	energy_required = 5,
	ingredients = {
		{type="fluid", name="adamo-carbon-natural-gas", amount=100, fluidbox_index = 2}
	},
	results= {
		{type="fluid", name="adamo-carbon-methane", amount=80, fluidbox_index = 1},
		{type="fluid", name="petroleum-gas", amount=10, fluidbox_index = 3},
	},
	icon = "__adamo-carbon__/graphics/icons/basic-natural-gas-processing.png",
	icon_size = 32,
	subgroup = "fluid-recipes",
	order = "a[oil-processing]-a1[adamo-carbon-basic-natural-gas-processing]"
}
adv_natural_gas_processing_recipe = {
	type = "recipe",
	name = "adamo-carbon-advanced-natural-gas-processing",
	category = "oil-processing",
	enabled = false,
	energy_required = 5,
	ingredients = {
		{type="fluid", name="adamo-carbon-natural-gas", amount=200, fluidbox_index = 2},
		--{type="item", name="iron-plate", amount=1}
	},
	results= {
		{type="fluid", name="adamo-carbon-methane", amount=160, fluidbox_index = 1},
		{type="fluid", name="light-oil", amount=10, fluidbox_index = 2},
		{type="fluid", name="petroleum-gas", amount=30, fluidbox_index = 3},
		{type="item", name="sulfur", amount=1},
	},
	icon = "__adamo-carbon__/graphics/icons/advanced-natural-gas-processing.png",
	icon_size = 32,
	subgroup = "fluid-recipes",
	order = "a[oil-processing]-a[adamo-carbon-advanced-natural-gas-processing]"
}
activated_fuel_recipe = {
	type = "recipe",
	name = "adamo-carbon-activated-solid-fuel",
	category = "chemistry",
	energy_required = 2,
	ingredients = {{
			type = "fluid",
			name = "adamo-carbon-methane",
			amount = 20
		},{
			type = "item",
			name = "coal",
			amount = 1
	}},
	result = "solid-fuel",
	icon = "__adamo-carbon__/graphics/icons/activated-solid-fuel.png",
	icon_size = 32,
	subgroup = "fluid-recipes",
	enabled = false,
	order = "b[fluid-chemistry]-d[adamo-carbon-activated-solid-fuel]"
}
LPG_cracking_recipe = {
	type = "recipe",
	name = "adamo-carbon-petroleum-gas-cracking",
	category = "chemistry",
	enabled = false,
	energy_required = 2,
	ingredients = {{
			type="fluid",
			name="water",
			amount=30
	},{
			type="fluid",
			name="petroleum-gas",
			amount=20
	}},
	results = {{
			type="fluid",
			name="adamo-carbon-methane",
			amount=10
	}},
	main_product= "",
	icon = "__adamo-carbon__/graphics/icons/petroleum-gas-cracking.png",
	icon_size = 32,
	subgroup = "fluid-recipes",
	order = "b[fluid-chemistry]-c1[adamo-carbon-petroleum-gas-cracking]",
	crafting_machine_tint = {
		primary = {r = 0.85, g = 0.46, b = 0.000, a = 0.000}, -- #c8670000
		secondary = {r = 0.82, g = 0.8, b = 0.605, a = 0.000}, -- #cacd9a00
		tertiary = {r = 0.81, g = 0.4, b = 0.000, a = 0.000}, -- #d48c0000
	}
}
-- oxidative coupling of methane to make ethylene
-- 2 methane + O2 => ethylene + 2 water (exo)
-- catalyst: 
-- steam reforming
-- methane + steam <=> CO + 3 H2 (endo)
-- catalyst: nickel
-- water-gas shift reaction
-- CO + steam <=> CO2 + H2 (exo)
-- catalyst: iron
-- Fischer-Tropsch
-- 10 methane + copper + iron + 10 steam => 10 CO + 30 H2
-- => 5 PG
FT_basic_recipe = {
	type = "recipe",
	name = "adamo-carbon-basic-FT-process",
	category = "oil-processing",
	enabled = false,
	energy_required = 2,
	ingredients = {{
			type="fluid",
			name="steam",
			amount=100,
			fluidbox_index = 1
	},{
			type="fluid",
			name="adamo-carbon-methane",
			amount=100,
			fluidbox_index = 2
	},{
			type="item",
			name="iron-plate",
			amount=1,
			catalyst_amount = 1
	}},
	results = {{
			type="fluid",
			name="heavy-oil",
			amount=2,
			fluidbox_index = 1,
	},{
			type="fluid",
			name="light-oil",
			amount=10,
			fluidbox_index = 2,
	},{
			type="item",
			name="iron-plate",
			amount=1,
			catalyst_amount = 1,
			probability = 0.8
	}},
	main_product= "light-oil",
	subgroup = "fluid-recipes",
	crafting_machine_tint = {
		primary = {r = 0.85, g = 0.46, b = 0.000, a = 0.000}, -- #c8670000
		secondary = {r = 0.82, g = 0.8, b = 0.605, a = 0.000}, -- #cacd9a00
		tertiary = {r = 0.81, g = 0.4, b = 0.000, a = 0.000}, -- #d48c0000
	}
}
FT_adv_recipe = {
	type = "recipe",
	name = "adamo-carbon-advanced-FT-process",
	category = "oil-processing",
	enabled = false,
	energy_required = 2,
	ingredients = {{
			type="fluid",
			name="steam",
			amount=100,
			fluidbox_index = 1
	},{
			type="fluid",
			name="adamo-carbon-methane",
			amount=100,
			fluidbox_index = 2		
	},{
			type="item",
			name="iron-plate",
			amount=1,
			catalyst_amount = 1
	},{
			type="item",
			name="copper-plate",
			amount=1,
			catalyst_amount = 1
	}},
	results = {{
			type="fluid",
			name="heavy-oil",
			amount=1,
			fluidbox_index = 1
	},{
			type="fluid",
			name="light-oil",
			amount=5,
			fluidbox_index = 2
	},{
			type="fluid",
			name="petroleum-gas",
			amount=20,
			fluidbox_index = 3
	},{
			type="item",
			name="iron-plate",
			amount=1,
			catalyst_amount = 1,
			probability = 0.8
	},{
			type="item",
			name="copper-plate",
			amount=1,
			catalyst_amount = 1,
			probability = 0.6
	}},
	main_product= "petroleum-gas",
	subgroup = "fluid-recipes",
	crafting_machine_tint = {
		primary = {r = 0.85, g = 0.46, b = 0.000, a = 0.000}, -- #c8670000
		secondary = {r = 0.82, g = 0.8, b = 0.605, a = 0.000}, -- #cacd9a00
		tertiary = {r = 0.81, g = 0.4, b = 0.000, a = 0.000}, -- #d48c0000
	}
}
crude_oil_fuel_recipe = util.table.deepcopy(data.raw.recipe["solid-fuel-from-heavy-oil"])
crude_oil_fuel_recipe.name = "adamo-carbon-solid-fuel-from-crude-oil"
crude_oil_fuel_recipe.ingredients = {{
	type = "fluid",
	name = "crude-oil",
	amount = 30
}}
crude_oil_fuel_recipe.icon = "__adamo-carbon__/graphics/icons/solid-fuel-from-crude-oil.png"
crude_oil_fuel_recipe.order = "b[fluid-chemistry]-f[adamo-carbon-solid-fuel-from-crude-oil]"
rocket_fuel_recipe = util.table.deepcopy(data.raw.recipe["rocket-fuel"])
rocket_fuel_recipe.name = "adamo-carbon-rocket-fuel"
rocket_fuel_recipe.category = "crafting-with-fluid"
rocket_fuel_recipe.ingredients = {{
		type = "fluid",
		name = "adamo-carbon-methane",
		amount = 200,
	},{
		type = "fluid",
		name = "water",
		amount = 400
	},{
		type = "item",
		name = "steel-plate",
		amount = 1
}}
natural_gas_wellhead_recipe = {
	type = "recipe",
	name = "adamo-carbon-gas-wellhead",
	enabled = false,
	ingredients = {{
			"electronic-circuit",5
		},{
			"iron-plate",5
		},{
			"pipe",10
		},{
			"steel-plate",2
		},{
			"pump",1
	}},
	result = "adamo-carbon-gas-wellhead"
}
gf_boiler_recipe = {
	type = "recipe",
	name = "adamo-carbon-gas-fired-boiler",
	enabled = false,
	ingredients = {{
			"stone-brick",5
		},{
			"pipe",5
		},{
			"pump",1
	}},
	result = "adamo-carbon-gas-fired-boiler"
}

apply_data()